@@ -24,7 +24,7 @@
 #' }
 NULL
 
-tar_format <- function(format) {
+tar_format_alias <- function(format) {
   out <- tar_format_api
   body(out) <- substitute({
     name <- targets::tar_deparse_language(substitute(name))
@@ -85,84 +85,84 @@ tar_format_api <- function(
 
 #' @export
 #' @rdname tar_formats
-tar_url <- tar_format("url")
+tar_url <- tar_format_alias("url")
 
 #' @export
 #' @rdname tar_formats
-tar_file <- tar_format("file")
+tar_file <- tar_format_alias("file")
 
 #' @export
 #' @rdname tar_formats
-tar_rds <- tar_format("rds")
+tar_rds <- tar_format_alias("rds")
 
 #' @export
 #' @rdname tar_formats
-tar_qs <- tar_format("qs")
+tar_qs <- tar_format_alias("qs")
 
 #' @export
 #' @rdname tar_formats
-tar_keras <- tar_format("keras")
+tar_keras <- tar_format_alias("keras")
 
 #' @export
 #' @rdname tar_formats
-tar_torch <- tar_format("torch")
+tar_torch <- tar_format_alias("torch")
 
 #' @export
 #' @rdname tar_formats
-tar_format_feather <- tar_format("feather")
+tar_format_feather <- tar_format_alias("feather")
 
 #' @export
 #' @rdname tar_formats
-tar_parquet <- tar_format("parquet")
+tar_parquet <- tar_format_alias("parquet")
 
 #' @export
 #' @rdname tar_formats
-tar_fst <- tar_format("fst")
+tar_fst <- tar_format_alias("fst")
 
 #' @export
 #' @rdname tar_formats
-tar_fst_dt <- tar_format("fst_dt")
+tar_fst_dt <- tar_format_alias("fst_dt")
 
 #' @export
 #' @rdname tar_formats
-tar_fst_tbl <- tar_format("fst_tbl")
+tar_fst_tbl <- tar_format_alias("fst_tbl")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_file <- tar_format("aws_file")
+tar_aws_file <- tar_format_alias("aws_file")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_rds <- tar_format("aws_rds")
+tar_aws_rds <- tar_format_alias("aws_rds")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_qs <- tar_format("aws_qs")
+tar_aws_qs <- tar_format_alias("aws_qs")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_keras <- tar_format("aws_keras")
+tar_aws_keras <- tar_format_alias("aws_keras")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_torch <- tar_format("aws_torch")
+tar_aws_torch <- tar_format_alias("aws_torch")
 
 #' @export
 #' @rdname tar_formats
-tar_format_aws_feather <- tar_format("aws_feather")
+tar_format_aws_feather <- tar_format_alias("aws_feather")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_parquet <- tar_format("aws_parquet")
+tar_aws_parquet <- tar_format_alias("aws_parquet")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_fst <- tar_format("aws_fst")
+tar_aws_fst <- tar_format_alias("aws_fst")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_fst_dt <- tar_format("aws_fst_dt")
+tar_aws_fst_dt <- tar_format_alias("aws_fst_dt")
 
 #' @export
 #' @rdname tar_formats
-tar_aws_fst_tbl <- tar_format("aws_fst_tbl")
+tar_aws_fst_tbl <- tar_format_alias("aws_fst_tbl")
