@@ -60,6 +60,7 @@ tar_rep_raw <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -76,6 +77,7 @@ tar_rep_raw <- function(
   batch <- tar_rep_batch(
     name_batch = name_batch,
     batches = batches,
+    repository = repository,
     error = error,
     memory = memory,
     garbage_collection = garbage_collection,
@@ -91,6 +93,7 @@ tar_rep_raw <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
@@ -108,6 +111,7 @@ tar_rep_raw <- function(
 tar_rep_batch <- function(
   name_batch,
   batches,
+  repository,
   error,
   memory,
   garbage_collection,
@@ -119,6 +123,7 @@ tar_rep_batch <- function(
     command = tar_rep_command_batch(batches),
     packages = character(0),
     format = "rds",
+    repository = repository,
     iteration = "vector",
     error = error,
     memory = memory,
@@ -140,6 +145,7 @@ tar_rep_target <- function(
   packages,
   library,
   format,
+  repository,
   iteration,
   error,
   memory,
@@ -158,6 +164,7 @@ tar_rep_target <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
