@@ -14,6 +14,10 @@ map_lgl <- function(x, f, ...) {
   vapply(X = x, FUN = as_function(f), FUN.VALUE = logical(1), ...)
 }
 
+map_rows <- function(x, f, ...) {
+  apply(X = x, MARGIN = 1L, FUN = as_function(f), ...)
+}
+
 set_names <- function(x, names) {
   names(x) <- unname(names)
   x
